.. _cmd_upgrade:

apio upgrade
============

.. contents::

Usage
-----

.. code::

    apio upgrade [OPTIONS]

Description
-----------

Check latest Apio version in https://pypi.python.org/pypi/apio.

Examples
--------

1. Check the Apio version

.. code::

  $ apio upgrade
  You're up-to-date!
  Apio 0.4.1 is currently the newest version available.
